@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 C.11.3 Bibliography and Citation (p208)
 
@@ -68,6 +66,10 @@ class thebibliography(List):
         def id(self):
             return self.attributes['key']
 
+        @id.setter
+        def id(self, value):
+            self.attributes['key'] = value
+
         @property
         def bibcite(self):
             doc = self.ownerDocument
