@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 C.9 Figures and Other Floating Bodies (p196)
 
@@ -141,11 +139,5 @@ class normalmarginpar(Command):
 
 # Style Parameters
 
-class marginparwidth(DimenCommand):
-    value = DimenCommand.new(0)
-
-class marginparsep(DimenCommand):
-    value = DimenCommand.new(0)
-
 class marginparpush(DimenCommand):
     value = DimenCommand.new(0)
