@@ -1,20 +1,11 @@
-#!/usr/bin/env python
-
 """
 C.5 Classes, Packages, and Page Styles (p176)
 
 """
-import sys, os
 from plasTeX import Command, Environment, DimenCommand, Token
 from plasTeX.Logging import getLogger
 
-# Put the plasTeX packages into the path
-from plasTeX import Packages
-sys.path.append(os.path.dirname(Packages.__file__))
-del Packages
-
 log = getLogger()
-status = getLogger('status')
 
 class PackageLoader(Command):
     extension = '.sty'
@@ -22,8 +13,9 @@ class PackageLoader(Command):
         try:
             self.ownerDocument.context.loadPackage(
                     tex, file+self.extension, options or {})
-        except Exception as msg:
-            log.error('Could not load package "%s": %s' % (file, msg))
+        except Exception as exc:
+            log.error('Loading package "%s" raised exception %s : %s' % (
+                file, type(exc).__name__, exc))
 
 #
 # C.5.1 Document Class
@@ -58,9 +50,6 @@ class columnsep(DimenCommand):
 class columnseprule(DimenCommand):
     value = DimenCommand.new(0)
 
-class mathindent(DimenCommand):
-    value = DimenCommand.new(0)
-
 #
 # C.5.2 Packages
 #
@@ -150,9 +139,6 @@ class marginparsep(DimenCommand):
 class marginparwidth(DimenCommand):
     value = DimenCommand.new('0.75in')
 
-class topskip(DimenCommand):
-    value = DimenCommand.new(0)
-
 #
 # C.5.4 The Title Page and Abstract
 #
