@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 C.3.1 Making Sentences (p170)
 
@@ -42,12 +40,6 @@ class EndOfSentence(Command):
     macroName = '@'
     str = ''
 
-class frenchspacing(Command): 
-    pass
-
-class nonfrenchspacing(Command):
-    pass
-
 #
 # Special characters
 #
