@@ -1,8 +1,6 @@
-#!/usr/bin/env python
-
-import datetime
+from datetime import datetime
 from plasTeX.Tokenizer import Token, EscapeSequence, Other
-from plasTeX import Command, CountCommand
+from plasTeX import Macro, Command, CountCommand
 from plasTeX import sourceChildren
 from plasTeX.Logging import getLogger
 
@@ -10,7 +8,6 @@ from plasTeX.Logging import getLogger
 log = getLogger()
 status = getLogger('status')
 deflog = getLogger('parse.definitions')
-envlog = getLogger('parse.environments')
 mathshiftlog = getLogger('parse.mathshift')
 
 class relax(Command):
@@ -81,7 +78,11 @@ class MathShift(Command):
         current = self.ownerDocument.createElement('math')
         for t in tex.itertokens():
             if t.catcode == Token.CC_MATHSHIFT:
-                current = self.ownerDocument.createElement('displaymath')
+                # Case where we have $   $$    $ construction
+                if inEnv and inEnv[-1] is not None and type(inEnv[-1]) is type(current):
+                    tex.pushToken(t)
+                else:
+                    current = self.ownerDocument.createElement('displaymath')
             else:
                 tex.pushToken(t)
             break
@@ -157,7 +158,14 @@ class DefCommand(Command):
                         newarg.append(t)
                         params = 0
                 a[key] = newarg
-        self.ownerDocument.context.newdef(a['name'], a['args'], a['definition'], local=self.local)
+
+        # nodeName works for both EscapeSequence and Macro. We can end up with
+        # a macro in the name position if we used \expandafter, e.g.
+        # \expandafter\def\csname foo\endcsname. This works even in the case
+        # where \foo is not yet defined, and becomes an unrecognized macro.
+        name = a['name'].nodeName
+
+        self.ownerDocument.context.newdef(name, a['args'], a['definition'], local=self.local)
 
 class def_(DefCommand):
     macroName = 'def'
@@ -197,7 +205,7 @@ class ifnum(IfCommand):
     def invoke(self, tex):
         self.parse(tex)
         attrs = self.attributes
-        attrs['b'] = tex.readNumber(optspace=False)
+        attrs['b'] = tex.readNumber()
         relation = attrs['rel']
         a, b = attrs['a'], attrs['b']
         if relation == '<':
@@ -233,13 +241,7 @@ class ifdim(IfCommand):
 class ifodd(IfCommand):
     """ Test for odd integer """
     def invoke(self, tex):
-        tex.processIfContent(bool(tex.readNumber(optspace=False) % 2))
-        return []
-
-class ifeven(IfCommand):
-    """ Test for even integer """
-    def invoke(self, tex):
-        tex.processIfContent(not(tex.readNumber(optspace=False) % 2))
+        tex.processIfContent(bool(tex.readNumber() % 2))
         return []
 
 class ifvmode(IfCommand):
@@ -287,28 +289,28 @@ class ifx(IfCommand):
 class ifvoid(IfCommand):
     """ Test a box register """
     def invoke(self, tex):
-        tex.readNumber(optspace=False)
+        tex.readNumber()
         tex.processIfContent(False)
         return []
 
 class ifhbox(IfCommand):
     """ Test a box register """
     def invoke(self, tex):
-        tex.readNumber(optspace=False)
+        tex.readNumber()
         tex.processIfContent(False)
         return []
 
 class ifvbox(IfCommand):
     """ Test a box register """
     def invoke(self, tex):
-        tex.readNumber(optspace=False)
+        tex.readNumber()
         tex.processIfContent(False)
         return []
 
 class ifeof(IfCommand):
     """ Test for end of file """
     def invoke(self, tex):
-        tex.readNumber(optspace=False)
+        tex.readNumber()
         tex.processIfContent(False)
         return []
 
@@ -340,9 +342,29 @@ class pdftrue(Command): pass
 class ifcase(IfCommand):
     """ Cases """
     def invoke(self, tex):
-        tex.processIfContent(tex.readNumber(optspace=False))
+        tex.processIfContent(tex.readNumber())
         return []
 
+class ifdefined(IfCommand):
+    args = 'name:Tok'
+    def invoke(self, tex):
+        a = self.parse(tex)
+        n = str(a['name'].macroName)
+        b = n in self.ownerDocument.context
+        tex.processIfContent(b)
+        return []
+
+class ifcsname(IfCommand):
+    def invoke(self, tex):
+        name = []
+        for t in tex:
+            if t.nodeType == Command.ELEMENT_NODE and t.nodeName == 'endcsname':
+                break
+            name.append(t)
+        n = ''.join(name)
+        b = n in self.ownerDocument.context
+        tex.processIfContent(b)
+        return []
 
 class let(Command):
     """ \\let """
@@ -373,10 +395,6 @@ class NameDef(Command):
     macroName = '@namedef'
     args = 'name:str value:nox'
 
-class makeatletter(Command):
-    def invoke(self, tex):
-        self.ownerDocument.context.catcode('@', Token.CC_LETTER)
-
 class everypar(Command):
     args = 'tokens:nox'
 
@@ -386,10 +404,11 @@ class catcode(Command):
     def invoke(self, tex):
         a = self.parse(tex)
         self.ownerDocument.context.catcode(chr(a['char']), a['code'])
+
+    @property
     def source(self):
         return r'\catcode`%s=%s' % (chr(self.attributes['char']),
                                      self.attributes['code'])
-    source = property(source)
 
 class csname(Command):
     """ \\csname """
@@ -407,19 +426,26 @@ class endcsname(Command):
 class input(Command):
     """ \\input """
     args = 'name:str'
+
     def invoke(self, tex):
         a = self.parse(tex)
+        assert a is not None
         try:
             path = tex.kpsewhich(a['name'])
-            status.info(' ( %s ' % path)
-            encoding = self.config['files']['input-encoding']
-            with open(path, encoding=encoding) as f:
-                tex.input(f.read())
-            status.info(' ) ')
-
+        except FileNotFoundError:
+            try:
+                path = tex.kpsewhich(a['name'] + '.tex')
+            except FileNotFoundError:
+                log.warning("File not found: " + a['name'])
+                return []
+        status.info(' ( %s ' % path)
+        encoding = self.config['files']['input-encoding']
+        try:
+            tex.input(open(path, encoding=encoding))
         except (OSError, IOError) as msg:
             log.warning(msg)
-            status.info(' ) ')
+        status.info(' ) ')
+        return []
 
 class endinput(Command):
     def invoke(self, tex):
@@ -468,16 +494,22 @@ class noligs_(Command):
 
 class expandafter(Command):
     def invoke(self, tex):
-        nexttok = None
-        for tok in tex.itertokens():
-            nextok = tok
-            break
-        for tok in tex:
-            aftertok = tok
-            break
-        tex.pushToken(aftertok)
-        tex.pushToken(nexttok)
-        return []
+        nexttok = next(tex.itertokens())
+        aftertok = next(tex.itertokens())
+
+        # We expand aftertok once, not recursively
+        expanded = None
+        if isinstance(aftertok, EscapeSequence):
+            obj = tex.ownerDocument.createElement(aftertok.macroName)
+            obj.contextDepth = aftertok.contextDepth
+            obj.parentNode = aftertok.parentNode
+            aftertok = obj
+        if isinstance(aftertok, Macro):
+            expanded = aftertok.invoke(tex)
+
+        expanded = expanded or [aftertok]
+
+        return [nexttok] + expanded
 
 class vskip(Command):
     args = 'size:Dimen'
@@ -519,12 +551,12 @@ class hfil(Command):
 class the(Command):
     args = 'arg:cs'
     def invoke(self, tex):
-        result = Command.invoke(self, tex) 
+        result = Command.invoke(self, tex)
         name = self.attributes['arg']
         if name == 'year':
-            return [Other(datetime.datetime.now().strftime('%Y'))]
+            return [Other(datetime.now().strftime('%Y'))]
         elif name == 'month':
-            return [Other(datetime.datetime.now().strftime('%-m'))]
+            return [Other(datetime.now().strftime('%-m'))]
         elif name == 'day':
-            return [Other(datetime.datetime.now().strftime('%-d'))]
+            return [Other(datetime.now().strftime('%-d'))]
         return [Other('???')]
