@@ -1,11 +1,9 @@
-#!/usr/bin/env python
-
 """
 B.5 Macros for text
 
 """
 
-from plasTeX import Command, Environment, sourceChildren
+from plasTeX import Command, sourceChildren
 
 class frenchspacing(Command):
     str = ''
@@ -133,15 +131,6 @@ class nointerlineskip(Command):
 class offinterlineskip(Command):
     pass
 
-class smallskip(Command):
-    pass
-
-class medskip(Command):
-    pass
-
-class bigskip(Command):
-    pass
-
 class TeXBreak(Command):
     macroName = 'break'
     str = ''
@@ -210,9 +199,6 @@ class textindent(Command):
 class narrower(Command):
     pass
 
-class raggedright(Environment):
-    pass
-
 #
 # Accents are done in the LaTeX package
 #
