@@ -1,7 +1,6 @@
-#!/usr/bin/env python
-
 from plasTeX.Base.TeX.Fonts import *
 from plasTeX.Base.TeX.Parameters import *
 from plasTeX.Base.TeX.Primitives import *
 from plasTeX.Base.TeX.Registers import *
 from plasTeX.Base.TeX.Text import *
+from plasTeX.Base.TeX.Numbers import *
