@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 from plasTeX import Command, TheCounter
 
 def ProcessOptions(options, document):
@@ -13,7 +11,7 @@ def ProcessOptions(options, document):
     # Sections
     context.newcounter('part', resetby='volume',
                        format='$part')
-    context.newcounter('chapter', resetby='part',
+    context.newcounter('chapter', resetby='volume',
                        format='$chapter')
     context.newcounter('section', resetby='chapter',
                        format='${thechapter}.${section}')
@@ -37,9 +35,9 @@ def ProcessOptions(options, document):
 
     # Floats
     context.newcounter('figure', resetby='chapter',
-                       format='${thechapter}.${figure}')
+                       format='${thechapter}.${figure}', trimLeft=True)
     context.newcounter('table', resetby='chapter',
-                       format='${thechapter}.${table}')
+                       format='${thechapter}.${table}', trimLeft=True)
     context.newcounter('topnumber')
     context.newcounter('bottomnumber')
     context.newcounter('totalnumber')
