@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 from plasTeX.Base.LaTeX.Arrays import tabular
 from plasTeX import Command, DimenCommand, CountCommand, GlueCommand 
 from plasTeX import dimen, glue, count
@@ -8,7 +6,6 @@ class LTleft(GlueCommand): value = glue('1fil')
 class LTright(GlueCommand): value = glue('1fil')
 class LTpre(GlueCommand): value = glue('1fil')
 class LTpost(GlueCommand): value = glue('1fil')
-class LTchunksize(DimenCommand): value = dimen('4in')
 class LTchunksize(CountCommand): value = count(20)
 
 class setlongtables(Command): pass
@@ -40,7 +37,7 @@ class longtable(tabular):
     class tabularnewline(Command): pass
 
     class LongTableEndRow(tabular.EndRow):
-        args = None
+        args = ''
         macroName = None
         digested = False
         def digest(self, tokens):
@@ -141,4 +138,4 @@ class longtable(tabular):
             self.pop(i)
 
 class LongTableStar(longtable):
-    macroName = 'longtable*'
\ No newline at end of file
+    macroName = 'longtable*'
