@@ -1,9 +1,7 @@
-#!/usr/bin/env python
-
 r"""
 natbib
 
-TODO: 
+TODO:
     - compress multiple years
     - \shortcites
     - Indexing features
@@ -11,45 +9,46 @@ TODO:
 
 """
 
-import plasTeX, re, string
+import re, string
 from plasTeX import Base, Text
 
-log = plasTeX.Logging.getLogger()
-
-PackageOptions = {}
-
 def ProcessOptions(options, document):
     """ Process package options """
-    context = document.context
-    if options is None:
-        return
-    PackageOptions.update(options)
-    for key, value in list(options.items()):
+    options = options or dict()
+    new_options = dict()
+    punct = {'post': bstyleoption(', '),
+             'open': bstyleoption('('),
+             'close':bstyleoption(')'),
+             'sep':  bstyleoption(';'),
+             'style':bstyleoption('a'),
+             'dates':bstyleoption(','),
+             'years':bstyleoption(',')}
+    for key, value in options.items():
         if key == 'numbers':
-            bibpunct.punctuation['style'] = 'n'
-            ProcessOptions({'square':True, 'comma':True}, document)
+            punct['style'] = 'n'
+            new_options.update({'square':True, 'comma':True})
         elif key == 'super':
-            bibpunct.punctuation['style'] = 's'
-            bibpunct.punctuation['open'] = ''
-            bibpunct.punctuation['close'] = ''
+            punct['style'] = 's'
+            punct['open'] = ''
+            punct['close'] = ''
         elif key == 'authoryear':
-            ProcessOptions({'round':True, 'colon':True}, document)
+            new_options.update({'round':True, 'colon':True})
         elif key == 'round':
-            bibpunct.punctuation['open'] = '('
-            bibpunct.punctuation['close'] = ')'
+            punct['open'] = '('
+            punct['close'] = ')'
         elif key == 'square':
-            bibpunct.punctuation['open'] = '['
-            bibpunct.punctuation['close'] = ']'
+            punct['open'] = '['
+            punct['close'] = ']'
         elif key == 'angle':
-            bibpunct.punctuation['open'] = '<'
-            bibpunct.punctuation['close'] = '>'
+            punct['open'] = '<'
+            punct['close'] = '>'
         elif key == 'curly':
-            bibpunct.punctuation['open'] = '{'
-            bibpunct.punctuation['close'] = '}'
+            punct['open'] = '{'
+            punct['close'] = '}'
         elif key == 'comma':
-            bibpunct.punctuation['sep'] = ','
+            punct['sep'] = ','
         elif key == 'colon':
-            bibpunct.punctuation['sep'] = ';'
+            punct['sep'] = ';'
         elif key == 'sectionbib':
             Base.bibliography.level = Base.section.level
         elif key == 'sort':
@@ -60,6 +59,7 @@ def ProcessOptions(options, document):
             pass
         elif key == 'nonamebreak':
             pass
+    document.userdata['natbib'] = {**options, **new_options, 'punctuation': punct}
 
 class bibliography(Base.bibliography):
 
@@ -69,7 +69,7 @@ class bibliography(Base.bibliography):
 
     def loadBibliographyFile(self, tex):
         doc = self.ownerDocument
-        # Clear out any bib info from the standard package.  
+        # Clear out any bib info from the standard package.
         # We have to get our info from the aux file.
         doc.userdata.setPath('bibliography/bibcites', {})
         self.ownerDocument.context.push(self)
@@ -80,7 +80,7 @@ class bibliography(Base.bibliography):
 
 class bibstyle(Base.Command):
     args = 'style:str'
-    
+
 class citestyle(Base.Command):
     args = 'style:str'
 
@@ -106,56 +106,50 @@ class citestyle(Base.Command):
 
     def invoke(self, tex):
         res = Base.Command.invoke(self, tex)
-        try: 
+        try:
             s = self.styles[self.attributes['style']]
         except KeyError:
         #    log.warning('Could not find bibstyle: "%s"',
         #                 self.attributes['style'])
             return res
-        p = bibpunct.punctuation
+        p = self.ownerDocument.userdata['natbib']['punctuation']
         for i, opt in enumerate(['post','open','close','sep','style','dates','years']):
             p[opt] = s[i]
-        return res    
+        return res
 
 class bstyleoption(Text):
-    """ Option that can only be overridden by package options, 
+    """ Option that can only be overridden by package options,
         citestyle, or bibpunct """
 
 class bibliographystyle(citestyle):
     def invoke(self, tex):
         res = Base.Command.invoke(self, tex)
-        try: 
+        try:
             s = self.styles[self.attributes['style']]
         except KeyError:
         #    log.warning('Could not find bibstyle: "%s"',
         #                 self.attributes['style'])
             return res
-        p = bibpunct.punctuation
+        p = self.ownerDocument.userdata['natbib']['punctuation']
         for i, opt in enumerate(['post','open','close','sep','style','dates','years']):
             if isinstance(p[opt], bstyleoption):
                 p[opt] = s[i]
-        return res    
-        
+        return res
+
 class bibpunct(Base.Command):
     """ Set up punctuation of citations """
     args = '[ post:str ] open:str close:str sep:str ' + \
            'style:str dates:str years:str'
-    punctuation = {'post': bstyleoption(', '), 
-                   'open': bstyleoption('('), 
-                   'close':bstyleoption(')'), 
-                   'sep':  bstyleoption(';'), 
-                   'style':bstyleoption('a'), 
-                   'dates':bstyleoption(','), 
-                   'years':bstyleoption(',')}
     def invoke(self, tex):
         res = Base.Command.invoke(self, tex)
-        for key, value in list(self.attributes.items()):
+        punct = self.ownerDocument.userdata['natbib']['punctuation']
+        for key, value in self.attributes.items():
             if value is None:
                 continue
-            elif type(value) == str or type(value) == str:
-                bibpunct.punctuation[key] = value
+            elif isinstance(value, str):
+                punct[key] = value
             else:
-                bibpunct.punctuation[key] = value.textContent            
+                punct[key] = value.textContent
         return res
 
 class bibcite(Base.Command):
@@ -182,7 +176,7 @@ class thebibliography(Base.thebibliography):
 
         @property
         def bibcite(self):
-            try: 
+            try:
                 doc = self.ownerDocument
                 return doc.userdata.getPath('bibliography/bibcites', {})[self.attributes['key']]
             except KeyError as msg:
@@ -198,15 +192,15 @@ class thebibliography(Base.thebibliography):
                 obj.append('??')
                 value.attributes[item] = obj
             return value
-            
-        def ref():
-            def fset(self, value):
-                pass
-            def fget(self):
-                return self.bibcite.textContent
-            return locals()
-        ref = property(**ref())
-    
+
+        @property # type: ignore # mypy#4125
+        def ref(self):
+            return self.bibcite.textContent
+
+        @ref.setter
+        def ref(self, value):
+            pass
+
 class harvarditem(thebibliography.bibitem):
     args = '[ abbrlabel ] label year key:str'
 
@@ -217,22 +211,27 @@ class NatBibCite(Base.cite):
     class Connector(str):
         pass
 
+    @property
+    def punctuation(self):
+        return self.ownerDocument.userdata['natbib']['punctuation']
+
     @property
     def bibitems(self):
         items = []
-        opts = PackageOptions
         doc = self.ownerDocument
+        opts = doc.userdata['natbib']
         b = doc.userdata.getPath('bibliography/bibitems', {})
         for key in self.attributes['bibkeys']:
             if key in b:
                 items.append(b[key])
-        if bibpunct.punctuation['style'] in 'ns' and \
-           ('sort' in opts or 'sort&compress' in opts or 'sortandcompress' in opts):
-            items.sort(lambda x, y: int(x.ref) - int(y.ref))
-            if 'sort&compress' in opts or 'sortandcompress' in opts:
-                items = self.compressRange(items)
+        if len(items) > 1:
+            if self.isNumeric() and \
+            ('sort' in opts or 'sort&compress' in opts or 'sortandcompress' in opts):
+                items.sort(key=lambda x: int(x.ref))
+                if 'sort&compress' in opts or 'sortandcompress' in opts:
+                    items = self.compressRange(items)
         return items
-        
+
     def compressRange(self, items):
         """ Compress ranges of numbers """
         idx, idxdict = [], {}
@@ -252,7 +251,7 @@ class NatBibCite(Base.cite):
                 output.append(value)
         output.append(' ')
         output = ''.join([str(x) for x in output])
-        output = re.sub(r'( \d+)-(\d+ )', r'\1 \2', output) 
+        output = re.sub(r'( \d+)-(\d+ )', r'\1 \2', output)
         while re.search(r'-\d+-', output):
             output = re.sub(r'-\d+-', r'-', output)
         output = [x for x in re.split(r'([ -])', output) if x.strip()]
@@ -262,10 +261,10 @@ class NatBibCite(Base.cite):
             else:
                 output[i] = self.Connector(value)
         return output
-        
+
     def isConnector(self, value):
         return isinstance(value, self.Connector)
-          
+
     @property
     def prenote(self):
         """ Text that comes before the citation """
@@ -287,54 +286,55 @@ class NatBibCite(Base.cite):
             if not a.get('text2').textContent.strip():
                 return ''
             out = self.ownerDocument.createElement('bgroup')
-            out.append(bibpunct.punctuation['post'])
+            out.append(self.punctuation['post'])
             out.extend(a['text2'])
             return out
         elif a.get('text') is not None:
             if not a.get('text').textContent.strip():
                 return ''
             out = self.ownerDocument.createElement('bgroup')
-            out.append(bibpunct.punctuation['post'])
+            out.append(self.punctuation['post'])
             out.extend(a['text'])
             return out
         return ''
-        
+
     @property
     def separator(self):
         """ Separator for multiple items """
-        return bibpunct.punctuation['sep']
+        return self.punctuation['sep']
 
     @property
     def dates(self):
         """ Separator between author and dates """
-        return bibpunct.punctuation['dates']
+        return self.punctuation['dates']
 
     @property
     def years(self):
         """ Separator for multiple years """
-        return bibpunct.punctuation['years']
+        return self.punctuation['years']
 
     def selectAuthorField(self, key, full=False):
         """ Determine if author should be a full name or shortened """
         if full or self.attributes.get('*modifier*'):
             return 'fullauthor'
-        doc = self.ownerDocument        
+        doc = self.ownerDocument
+        opts = doc.userdata['natbib']
         # longnamesfirst means that only the first reference
         # gets the full length name, the rest use short names.
         cited = doc.userdata.getPath('bibliography/cited', [])
-        if 'longnamesfirst' in PackageOptions and key not in cited:
+        if 'longnamesfirst' in opts and key not in cited:
             full = True
             cited.append(key)
         doc.userdata.setPath('bibliography/cited', cited)
         if full:
             return 'fullauthor'
         return 'author'
-        
+
     def isNumeric(self):
-        return bibpunct.punctuation['style'] in ['n','s']
-        
+        return self.punctuation['style'] in ['n','s']
+
     def isSuperScript(self):
-        return bibpunct.punctuation['style'] == 's'
+        return self.punctuation['style'] == 's'
 
     def citeValue(self, item, text=None):
         """ Return cite value based on current style """
@@ -342,7 +342,7 @@ class NatBibCite(Base.cite):
         b.idref['bibitem'] = item
         if text is not None:
             b.append(text)
-        elif bibpunct.punctuation['style'] in ['n','s']:
+        elif self.punctuation['style'] in ['n','s']:
             b.append(item.bibcite)
         else:
             b.append(item.bibcite.attributes['year'])
@@ -357,36 +357,37 @@ class NatBibCite(Base.cite):
             return item
         node = textnodes.pop(0)
         node.parentNode.replaceChild(node.cloneNode(True).capitalize() ,node)
-        return item        
-            
+        return item
+
 # class citep(NatBibCite):
 
 #     def numcitation(self):
 #         """ Numeric style citations """
 #         res = []
-#         res.append(bibpunct.punctuation['open'])
+#         res.append(self.punctuation['open'])
 #         for i, item in enumerate(self.bibitems):
 #             frag = self.ownerDocument.createDocumentFragment()
 #             frag.append(item.ref)
 #             frag.idref = item
 #             res.append(frag)
-#             res.append(bibpunct.punctuation['sep'])
+#             res.append(self.punctuation['sep'])
 #         res.pop()
-#         res.append(bibpunct.punctuation['close'])
+#         res.append(self.punctuation['close'])
 #         return res
 
 #     def citation(self):
-#         if bibpunct.punctuation['style'] == 'n':
+#         if self.punctuation['style'] == 'n':
 #             return self.numcitation()
-#         elif bibpunct.punctuation['style'] == 's':
+#         elif self.punctuation['style'] == 's':
 #             return self.numcitation()
 
 #         res = []
-#         res.append(bibpunct.punctuation['open'] + self.prenote)
+#         res.append(self.punctuation['open'] + self.prenote)
 #         prevauthor = None
 #         prevyear = None
 #         duplicateyears = 0
 #         previtem = None
+#         opts = self.ownerDocument.userdata['natbib']
 #         for i, item in enumerate(self.bibitems):
 #             currentauthor = item.citeauthor().textContent
 #             currentyear = item.citeyear().textContent
@@ -398,7 +399,7 @@ class NatBibCite(Base.cite):
 #                 if duplicateyears == 0:
 #                     # Make a reference that points to the same item as
 #                     # the first citation in this set.  This will make
-#                     # hyperlinked output prettier since the 'a' will 
+#                     # hyperlinked output prettier since the 'a' will
 #                     # be linked to the same place as the reference that
 #                     # we just put out.
 #                     res.append('')
@@ -406,45 +407,45 @@ class NatBibCite(Base.cite):
 #                     frag.append('a')
 #                     frag.idref = previtem
 #                     res.append(frag)
-#                     res.append(bibpunct.punctuation['years'])
+#                     res.append(self.punctuation['years'])
 #                 else:
-#                     res.append(bibpunct.punctuation['years'])
+#                     res.append(self.punctuation['years'])
 #                 # Create a new fragment with b,c,d... in it
 #                 frag = self.ownerDocument.createDocumentFragment()
 #                 frag.append(chr(duplicateyears+ord('b')))
 #                 frag.idref = item
 #                 res.append(frag)
-#                 res.append(bibpunct.punctuation['sep']+' ')
+#                 res.append(self.punctuation['sep']+' ')
 #                 duplicateyears += 1
 
 #             # Previous author is the same
 #             elif prevauthor == currentauthor:
 #                 duplicateyears = 0
 #                 res.pop()
-#                 res.append(bibpunct.punctuation['years']+' ')
+#                 res.append(self.punctuation['years']+' ')
 #                 res.append(item.citeyear())
-#                 res.append(bibpunct.punctuation['sep']+' ')
+#                 res.append(self.punctuation['sep']+' ')
 
 #             # Nothing about the previous citation is the same
 #             else:
 #                 doc = self.ownerDocument
 #                 cited = doc.userdata.getPath('bibliography/cited', [])
 #                 duplicateyears = 0
-#                 if 'longnamesfirst' in PackageOptions and \
+#                 if 'longnamesfirst' in opts and \
 #                    item.attributes['key'] not in cited:
 #                     cited.append(item.attributes['key'])
 #                     doc.userdata.setPath('bibliography/cited', cited)
 #                     res.append(item.citealp(full=True))
 #                 else:
 #                     res.append(item.citealp())
-#                 res.append(bibpunct.punctuation['sep']+' ')
+#                 res.append(self.punctuation['sep']+' ')
 
 #             prevauthor = currentauthor
 #             prevyear = currentyear
 #             previtem = item
 
 #         res.pop()
-#         res.append(self.postnote + bibpunct.punctuation['close'])
+#         res.append(self.postnote + self.punctuation['close'])
 #         return res
 
 class citet(NatBibCite):
@@ -456,7 +457,8 @@ class citet(NatBibCite):
         res = self.ownerDocument.createDocumentFragment()
         i = 0
         sameauthor = prevauthor = None
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             if text is None:
                 if not item.bibcite.attributes:
                     continue
@@ -477,23 +479,23 @@ class citet(NatBibCite):
                     else:
                         res.extend(item.bibcite.attributes[author])
                     res.append(' ')
-                    res.append(bibpunct.punctuation['open'])
+                    res.append(self.punctuation['open'])
                     # Prenote
                     res.append(self.prenote)
             # Year or text
             res.append(self.citeValue(item, text=text))
             # Separator, postnote, and closing punctuation
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 if text is None:
-                    res.append(bibpunct.punctuation['close'])
+                    res.append(self.punctuation['close'])
                     res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
                 if text is None:
-                    res.append(bibpunct.punctuation['close'])
+                    res.append(self.punctuation['close'])
         return res
 
-    def numcitation(self, full=False, capitalize=False):
+    def numcitation(self):
         """ (1, 2) """
         element = self.ownerDocument.createElement
         orig = res = self.ownerDocument.createDocumentFragment()
@@ -504,16 +506,17 @@ class citet(NatBibCite):
             group.append(res)
         i = 0
         res.append(self.prenote)
-        res.append(bibpunct.punctuation['open'])
-        for i, item in enumerate(self.bibitems):
+        res.append(self.punctuation['open'])
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             if self.isConnector(item):
                 res.pop()
                 res.append('-')
                 continue
             res.append(self.citeValue(item))
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
-        res.append(bibpunct.punctuation['close'])
+        res.append(self.punctuation['close'])
         res.append(self.postnote)
         return orig
 
@@ -521,7 +524,7 @@ class citetfull(citet):
 
     def citation(self):
         """ Jones, Baker, and Williams (1990) """
-        return citet.citation(self, full=True)        
+        return citet.citation(self, full=True)
 
 class Citet(citet):
 
@@ -535,11 +538,12 @@ class citep(NatBibCite):
         if text is None and self.isNumeric():
             return self.numcitation()
         res = self.ownerDocument.createDocumentFragment()
-        res.append(bibpunct.punctuation['open'])
+        res.append(self.punctuation['open'])
         res.append(self.prenote)
         i = 0
         sameauthor = prevauthor = None
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             if text is None:
                 if item.bibcite.attributes is None:
                     continue
@@ -554,15 +558,15 @@ class citep(NatBibCite):
                     author = self.selectAuthorField(item.attributes['key'], full=full)
                     if i == 0 and capitalize:
                         res.extend(self.capitalize(item.bibcite.attributes[author]))
-                    else:            
+                    else:
                         res.extend(item.bibcite.attributes[author])
                     res.append(self.dates+' ')
             res.append(self.citeValue(item, text=text))
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
-                res.append(bibpunct.punctuation['close'])
+                res.append(self.punctuation['close'])
         return res
 
     def numcitation(self):
@@ -574,20 +578,21 @@ class citep(NatBibCite):
             orig.append(group)
             res = element('active::^')
             group.append(res)
-        res.append(bibpunct.punctuation['open'])
+        res.append(self.punctuation['open'])
         res.append(self.prenote)
         i = 0
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             if self.isConnector(item):
                 res.pop()
                 res.append('-')
                 continue
             res.append(self.citeValue(item))
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
-                res.append(bibpunct.punctuation['close'])
+                res.append(self.punctuation['close'])
         return orig
 
 class cite(citep, citet):
@@ -622,7 +627,8 @@ class citealt(NatBibCite):
         res = self.ownerDocument.createDocumentFragment()
         i = 0
         prevauthor = sameauthor = None
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             if not item.bibcite.attributes:
                 fullauthor = '???'
             else:
@@ -644,7 +650,7 @@ class citealt(NatBibCite):
                 res.append(' ')
                 res.append(self.prenote)
             res.append(self.citeValue(item))
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
@@ -661,13 +667,14 @@ class citealt(NatBibCite):
             group.append(res)
         i = 0
         res.append(self.prenote)
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             if self.isConnector(item):
                 res.pop()
                 res.append('-')
                 continue
             res.append(self.citeValue(item))
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
@@ -678,11 +685,11 @@ class citealtfull(citealt):
     def citation(self):
         """ Jones, Baker, and Williams 1990 """
         return citealt.citation(self, full=True)
-    
+
 class Citealt(citealt):
 
     def citation(self):
-        return citealt.citation(self, capitalize=True)   
+        return citealt.citation(self, capitalize=True)
 
 class citealp(NatBibCite):
 
@@ -694,7 +701,8 @@ class citealp(NatBibCite):
         res.append(self.prenote)
         i = 0
         prevauthor = sameauthor = None
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             if not item.bibcite.attributes:
                 fullauthor = '???'
             else:
@@ -712,10 +720,10 @@ class citealp(NatBibCite):
                 elif i == 0 and capitalize:
                     res.extend(self.capitalize(item.bibcite.attributes[author]))
                 else:
-                    res.extend(item.bibcite.attributes[author])              
+                    res.extend(item.bibcite.attributes[author])
                 res.append(self.separator+' ')
             res.append(self.citeValue(item))
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
@@ -732,13 +740,14 @@ class citealp(NatBibCite):
             group.append(res)
         res.append(self.prenote)
         i = 0
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             if self.isConnector(item):
                 res.pop()
                 res.append('-')
                 continue
             res.append(self.citeValue(item))
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
         res.append(self.postnote)
         return orig
@@ -753,7 +762,7 @@ class Citealp(citealp):
 
     def citation(self):
         return citealp.citation(self, capitalize=True)
-        
+
 class citeauthor(NatBibCite):
 
     def citation(self, full=False, capitalize=False):
@@ -763,7 +772,8 @@ class citeauthor(NatBibCite):
         res = self.ownerDocument.createDocumentFragment()
         #res.append(self.prenote)
         i = 0
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             author = self.selectAuthorField(item.attributes['key'], full=full)
             b = self.ownerDocument.createElement('bibliographyref')
             b.idref['bibitem'] = item
@@ -774,7 +784,7 @@ class citeauthor(NatBibCite):
             else:
                 b.append(item.bibcite.attributes[author])
             res.append(b)
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
@@ -787,10 +797,10 @@ class citefullauthor(citeauthor):
         return citeauthor.citation(self, full=True)
 
 class Citeauthor(citeauthor):
-    
+
     def citation(self):
         return citeauthor.citation(self, capitalize=True)
-        
+
 class citeyear(NatBibCite):
 
     def citation(self):
@@ -800,7 +810,8 @@ class citeyear(NatBibCite):
         res = self.ownerDocument.createDocumentFragment()
         #res.append(self.prenote)
         i = 0
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             b = self.ownerDocument.createElement('bibliographyref')
             b.idref['bibitem'] = item
             if not item.bibcite.attributes:
@@ -808,7 +819,7 @@ class citeyear(NatBibCite):
             else:
                 b.append(item.bibcite.attributes['year'])
             res.append(b)
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
@@ -821,10 +832,11 @@ class citeyearpar(NatBibCite):
         if self.isNumeric():
             return
         res = self.ownerDocument.createDocumentFragment()
-        res.append(bibpunct.punctuation['open'])
+        res.append(self.punctuation['open'])
         res.append(self.prenote)
         i = 0
-        for i, item in enumerate(self.bibitems):
+        bibitems = self.bibitems
+        for i, item in enumerate(bibitems):
             b = self.ownerDocument.createElement('bibliographyref')
             b.idref['bibitem'] = item
             if not item.bibcite.attributes:
@@ -832,18 +844,19 @@ class citeyearpar(NatBibCite):
             else:
                 b.append(item.bibcite.attributes['year'])
             res.append(b)
-            if i < (len(self.bibitems)-1):
+            if i < (len(bibitems)-1):
                 res.append(self.separator+' ')
             else:
                 res.append(self.postnote)
-        res.append(bibpunct.punctuation['close'])
+        res.append(self.punctuation['close'])
         return res
-    
+
 class citetext(Base.Command):
     args = 'self'
     def digest(self, tokens):
-        self.insert(0, bibpunct.punctuation['open'])
-        self.append(bibpunct.punctuation['close'])
+        punct = self.ownerDocument.userdata['natbib']['punctuation']
+        self.insert(0, punct['open'])
+        self.append(punct['close'])
 
 class defcitealias(Base.Command):
     args = 'key:str text'
