@@ -1,8 +1,6 @@
-#!/usr/bin/env python
-
 from plasTeX.Packages.book import *
 from plasTeX.Packages import book
 
-def ProcessOptions(options, document):
+def ProcessOptions(options, document): # type: ignore
     book.ProcessOptions(options, document)
     document.context['theequation'].format = '${equation}'
