@@ -14,6 +14,7 @@ Example:
 
 """
 from io import IOBase
+from typing import Optional, List
 import string, os, sys, plasTeX, subprocess
 from plasTeX.Tokenizer import Tokenizer, Token, EscapeSequence, Other
 from plasTeX import TeXDocument
@@ -169,7 +170,7 @@ class TeX(object):
         if self.inputs:
             old_input = self.inputs.pop()
             try:
-                old_input.source.close()
+                old_input[0].source.close()
             except AttributeError:
                 pass
         if self.inputs:
@@ -441,8 +442,6 @@ class TeX(object):
         """
         Push a token back into the token buffer to be re-read
 
-        This method also pops an item off of the output token stream.
-
         Required Arguments:
         token -- token to push back
 
@@ -597,7 +596,8 @@ class TeX(object):
 
     def readArgumentAndSource(self, spec=None, type=None, subtype=None,
                     delim=',', expanded=False, default=None, parentNode=None,
-                    name=None, stripLeadingWhitespace=True):
+                    name=None, stripLeadingWhitespace=True,
+                    charsubs: Optional[List] = None):
         """
         Get an argument and the TeX source that created it
 
@@ -626,6 +626,10 @@ class TeX(object):
         name -- the name of the argument being parsed
         stripLeadingWhitespace -- if True, whitespace is skipped before
             looking for the argument
+        charsubs -- a list of character substitution to apply to the
+            argument. If None is provided then the document charsubs
+            attribute will be used if it exists, otherwise an empty
+            list will be used.
 
         Returns:
         tuple where the first argument is:
@@ -644,6 +648,9 @@ class TeX(object):
         # Disable expansion of parameters
         ParameterCommand.disable()
 
+        if charsubs is None:
+            charsubs = getattr(self.ownerDocument, 'charsubs', [])
+
         if type in ['Dimen','Length','Dimension']:
             n = self.readDimen()
             ParameterCommand.enable()
@@ -764,7 +771,7 @@ class TeX(object):
         # Normalize any document fragments
         if expanded and \
            getattr(res,'nodeType',None) == Macro.DOCUMENT_FRAGMENT_NODE:
-            res.normalize(getattr(self.ownerDocument, 'charsubs', []))
+            res.normalize(charsubs)
 
         # Re-enable Parameters
         ParameterCommand.enable()
