@@ -1,4 +1,4 @@
-__version__ = '2.1'
+__version__ = '3.1'
 
 from typing import Optional, Union, List, Callable, Dict
 from plasTeX import Logging, encoding
@@ -658,6 +658,9 @@ class Macro(Element):
                     argdict['expanded'] = False
                 else:
                     argdict['expanded'] = True
+                if argdict.get('type') == 'url':
+                    argdict['charsubs'] = []
+
                 macroargs.append(Argument(item, index, argdict))
                 index += 1
                 argdict.clear()
@@ -1105,7 +1108,7 @@ def expandDef(definition, params):
                 if t.catcode == Token.CC_PARAMETER:
                     output.append(t)
                 else:
-                    if params[int(t)] is not None:
+                    if int(t) < len(params) and params[int(t)] is not None:
                         # This is a pretty bad hack, but `ifx' commands
                         # need an argument to also be a token.  So we
                         # wrap them in a group here and let the
