@@ -1,8 +1,5 @@
-#!/usr/bin/env python
-
 import unittest
 from unittest import TestCase
-from plasTeX import Macro
 from plasTeX.TeX import *
 
 class ActiveChars(TestCase):
