@@ -1,21 +1,15 @@
 import os
 
-# Will try to use obsolete, but good enough for us, BeautifulSoup 3 if
-# BeautifulSoup 4 is not available. Need to cope with slight API difference
-try:
-    from bs4 import BeautifulSoup
-
-    def Soup(source):
-        return BeautifulSoup(source, 'html.parser')
-except ImportError:
-    from BeautifulSoup import BeautifulSoup as Soup
+from bs4 import BeautifulSoup
 
 from pytest import fixture
 
 from plasTeX.TeX import TeX, TeXDocument
-from plasTeX.Config import config
+from plasTeX.Config import defaultConfig
 from plasTeX.Renderers.XHTML import Renderer
 
+def Soup(source):
+    return BeautifulSoup(source, 'html.parser')
 
 @fixture(scope='session')
 def make_document():
@@ -31,7 +25,7 @@ def make_document():
 
         """
 
-        doc = TeXDocument(config=config)
+        doc = TeXDocument(config=defaultConfig())
         tex = TeX(doc)
         tex.disableLogging()
         tex.input(r'''
@@ -50,8 +44,9 @@ def renderXHTML():
         # Create document file
 
         # Run plastex on the document
-        os.chdir(str(tmpdir))
-        Renderer().render(doc)
+        with tmpdir.as_cwd():
+            Renderer().render(doc)
+
         assert tmpdir.join('index.html').isfile()
 
         # Get output file
